---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Test environment**
- Host OS version.
- Target device model and iOS version.

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Logs**
If applicable, add logs including backtraces for the given error that help explain your problem.

**Additional context**
Add any other context about the problem here.

## For community
⬇️  **Please click the 👍 reaction instead of leaving a `+1` or 👍  comment**